==> bibledit-0.9.tar.gz: bibledit-0.9/src/dialogprintproject2.h <==
/*
** Copyright (C) 2003 The Free Software Foundation.
**  
** This program is free software; you can redistribute it and/or modify
** it under the terms of the GNU General Public License as published by
** the Free Software Foundation; either version 2 of the License, or
** (at your option) any later version.
**  
** This program is distributed in the hope that it will be useful,
** but WITHOUT ANY WARRANTY; without even the implied warranty of
** MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
** GNU General Public License for more details.
**  
** You should have received a copy of the GNU General Public License
** along with this program; if not, write to the Free Software
** Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
**  
*/

#ifndef INCLUDED_DIALOGPRINTPROJECT2_H
#define INCLUDED_DIALOGPRINTPROJECT2_H

#include <gtk/gtk.h>
#include "scripture.h"
#include "ustring.h"
#include "configuration.h"


class PrintProject2Dialog
{
public:
  PrintProject2Dialog (Scripture *scripture_in, Configuration * configuration_in);
  virtual ~PrintProject2Dialog ();
  virtual int run ();
protected:
  GtkWidget *printproject2dialog;
  GtkWidget *dialog_vbox1;
  GtkWidget *vbox1;
  GtkWidget *coverpagecheckbutton;
  GtkWidget *titlepagecheckbutton;
  GtkWidget *introductioncheckbutton;
  GtkWidget *tablecontentscheckbutton;
  GtkWidget *ottitlecheckbutton;
  GtkWidget *table1;
  GtkWidget *label1;
  GtkWidget *label2;
  GtkWidget *combo_ot_book_to;
  GtkWidget *combo_entry_ot_book_to;
  GtkWidget *combo_ot_chapter_from;
  GtkWidget *combo_entry_ot_chapter_from;
  GtkWidget *combo_ot_chapter_to;
  GtkWidget *combo_entry_ot_chapter_to;
  GtkWidget *otcheckbutton;
  GtkWidget *combo_ot_book_from;
  GtkWidget *combo_entry_ot_book_from;
  GtkWidget *nttitlecheckbutton;
  GtkWidget *table2;
  GtkWidget *ntcheckbutton;
  GtkWidget *label3;
  GtkWidget *label4;
  GtkWidget *combo_nt_book_from;
  GtkWidget *combo_entry_nt_book_from;
  GtkWidget *combo_nt_chapter_from;
  GtkWidget *combo_entry_nt_chapter_from;
  GtkWidget *combo_nt_book_to;
  GtkWidget *combo_entry_nt_book_to;
  GtkWidget *combo_nt_chapter_to;
  GtkWidget *combo_entry_nt_chapter_to;
  GtkWidget *wordexplanationcheckbutton;
  GtkWidget *dialog_action_area1;
  GtkWidget *cancelbutton1;
  GtkWidget *okbutton1;
  static void on_combo_entry_ot_book_to_changed (GtkEditable *editable, gpointer user_data);
  static void on_combo_entry_ot_chapter_from_changed (GtkEditable *editable, gpointer user_data);
  static void on_combo_entry_ot_chapter_to_changed (GtkEditable *editable, gpointer user_data);
  static void on_otcheckbutton_toggled (GtkToggleButton *togglebutton, gpointer user_data);
  static void on_combo_entry_ot_book_from_changed (GtkEditable *editable, gpointer user_data);
  static void on_ntcheckbutton_toggled (GtkToggleButton *togglebutton, gpointer user_data);
  static void on_combo_entry_nt_book_from_changed (GtkEditable *editable, gpointer user_data);
  static void on_combo_entry_nt_chapter_from_changed (GtkEditable *editable, gpointer user_data);
  static void on_combo_entry_nt_book_to_changed (GtkEditable *editable, gpointer user_data);
  static void on_combo_entry_nt_chapter_to_changed (GtkEditable *editable, gpointer user_data);
  static void on_okbutton1_clicked (GtkButton *button, gpointer user_data);
  virtual void on_okbutton ();
private:
  Scripture *scripture;
  Configuration * configuration;
};


#endif

==> bibledit-1.4.tar.gz: bibledit-1.4/src/dialogprintproject2.h <==
/*
** Copyright (C) 2003 The Free Software Foundation.
**  
** This program is free software; you can redistribute it and/or modify
** it under the terms of the GNU General Public License as published by
** the Free Software Foundation; either version 2 of the License, or
** (at your option) any later version.
**  
** This program is distributed in the hope that it will be useful,
** but WITHOUT ANY WARRANTY; without even the implied warranty of
** MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
** GNU General Public License for more details.
**  
** You should have received a copy of the GNU General Public License
** along with this program; if not, write to the Free Software
** Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
**  
*/

#ifndef INCLUDED_DIALOGPRINTPROJECT2_H
#define INCLUDED_DIALOGPRINTPROJECT2_H

#include <gtk/gtk.h>
#include "scripture.h"
#include "ustring.h"
#include "configuration.h"


class PrintProject2Dialog
{
public:
  PrintProject2Dialog (Scripture *scripture_in, Configuration * configuration_in);
  virtual ~PrintProject2Dialog ();
  virtual int run ();
protected:
  GtkWidget *printproject2dialog;
  GtkWidget *dialog_vbox1;
  GtkWidget *vbox1;
  GtkWidget *coverpagecheckbutton;
  GtkWidget *titlepagecheckbutton;
  GtkWidget *introductioncheckbutton;
  GtkWidget *tablecontentscheckbutton;
  GtkWidget *ottitlecheckbutton;
  GtkWidget *table1;
  GtkWidget *label1;
  GtkWidget *label2;
  GtkWidget *combobox_ot_book_to;
  GtkWidget *combobox_ot_chapter_from;
  GtkWidget *combobox_ot_chapter_to;
  GtkWidget *otcheckbutton;
  GtkWidget *combobox_ot_book_from;
  GtkWidget *nttitlecheckbutton;
  GtkWidget *table2;
  GtkWidget *ntcheckbutton;
  GtkWidget *label3;
  GtkWidget *label4;
  GtkWidget *combobox_nt_book_from;
  GtkWidget *combobox_nt_chapter_from;
  GtkWidget *combobox_nt_book_to;
  GtkWidget *combobox_nt_chapter_to;
  GtkWidget *wordexplanationcheckbutton;
  GtkWidget *dialog_action_area1;
  GtkWidget *cancelbutton1;
  GtkWidget *okbutton1;
  static void on_combo_entry_ot_book_to_changed (GtkEditable *editable, gpointer user_data);
  static void on_combo_entry_ot_chapter_from_changed (GtkEditable *editable, gpointer user_data);
  static void on_combo_entry_ot_chapter_to_changed (GtkEditable *editable, gpointer user_data);
  static void on_otcheckbutton_toggled (GtkToggleButton *togglebutton, gpointer user_data);
  static void on_combo_entry_ot_book_from_changed (GtkEditable *editable, gpointer user_data);
  static void on_ntcheckbutton_toggled (GtkToggleButton *togglebutton, gpointer user_data);
  static void on_combo_entry_nt_book_from_changed (GtkEditable *editable, gpointer user_data);
  static void on_combo_entry_nt_chapter_from_changed (GtkEditable *editable, gpointer user_data);
  static void on_combo_entry_nt_book_to_changed (GtkEditable *editable, gpointer user_data);
  static void on_combo_entry_nt_chapter_to_changed (GtkEditable *editable, gpointer user_data);
  static void on_okbutton1_clicked (GtkButton *button, gpointer user_data);
  virtual void on_okbutton ();
private:
  Scripture *scripture;
  Configuration * configuration;
};


#endif
